@@ -2,7 +2,7 @@
  * File:	cmd-misc.c
  * Purpose:	Functions that implement commands.
  * Author:	Lars Wirzenius
- * Version:	"@(#)SeX:$Id: cmd-misc.c,v 1.17 1996/12/08 15:32:19 liw Exp $"
+ * Version:	"@(#)SeX:$Id: cmd-misc.c,v 1.19 2000/09/09 09:22:51 liw Exp $"
  */
 
 #include <assert.h>
@@ -106,6 +106,55 @@ int cmd_undent_selection(struct win *win) {
 }
 
 
+/*
+ * Function:	cmd_insert_indent
+ * Purpose:	If the selection is empty, insert tabs and spaces to
+ *		move it to the next indent level. If it is non-empty,
+ *		do nothing.
+ */
+int cmd_insert_indent(struct win *win) {
+	Sbuf *buf;
+	Sbufmark *sel;
+	long col, wanted_col, indent;
+
+	anchor_up(win);	
+	cmd_prev_was_cut = 0;
+
+	buf = win_buf(win);
+	sel = win_selection(win);
+
+	if (sbuf_mark_length(sel) > 0)
+		return 0;
+
+	indent = config_get_long(CONFIG_INDENT_WIDTH);
+	col = sbuf_colno(buf, sbuf_mark_begin(sel), tab_width());
+	wanted_col = col + indent - (col % indent);
+
+	while (tab_next(col) <= wanted_col) {
+		if (sbuf_strchange(sel, "\t", 1) == -1) {
+			error(win, "error changing buffer (out of memory?)");
+			return -1;
+		}
+		sbuf_remark(sel, sbuf_mark_end(sel), 0);
+		col = tab_next(col);
+	}
+
+	while (col < wanted_col) {
+		if (sbuf_strchange(sel, " ", 1) == -1) {
+			error(win, "error changing buffer (out of memory?)");
+			return -1;
+		}
+		sbuf_remark(sel, sbuf_mark_end(sel), 0);
+		++col;
+	}
+
+	win_show(win, sbuf_mark_begin(sel));
+	
+	return 0;
+}
+
+
+
 
 /*
  * Function:	cmd_indent_line
@@ -314,7 +363,7 @@ static long current_indent(Sbuf *buf, long pos, long begin) {
  *		begin	limit for indentation computation
  */
 static long wanted_indent(Sbuf *buf, long pos, long begin) {
-	long i, j, col, prev, tab;
+	long i, j, col, prev, tab, indent;
 	int c;
 
 	if (pos == 0)
@@ -325,6 +374,7 @@ static long wanted_indent(Sbuf *buf, long pos, long begin) {
 	i = next_nonspace(buf, prev, begin);
 	col = sbuf_colno(buf, i, tab_width());
 	tab = tab_width();
+	indent = config_get_long(CONFIG_INDENT_WIDTH);
 
 	j = next_nonspace(buf, pos, begin);
 	c = sbuf_charat(buf, j);
@@ -337,7 +387,7 @@ static long wanted_indent(Sbuf *buf, long pos, long begin) {
 	} else {
 		c = sbuf_charat(buf, prev_nonspace(buf, pos-1));
 		if (c == '{' || c == '(' || c == '[')
-			col = tab_next(col);
+			col += indent - (col % indent);
 	}
 
 	return col;
