@@ -2,7 +2,7 @@
  * File:	win.c
  * Purpose:	Implement top level windows.
  * Author:	Lars Wirzenius
- * Version:	"@(#)SeX:$Id: win.c,v 1.58 1997/09/19 21:35:18 liw Exp $"
+ * Version:	"@(#)SeX:$Id: win.c,v 1.59 1999/08/07 21:28:49 liw Exp $"
  */
 
 #include <assert.h>
@@ -601,8 +601,20 @@ void win_set_title(struct win *win) {
 	s = sbuf_get_name(buf);
 	if (s == NULL)
 		s = "(untitled)";
+#if 0
 	sprintf(title_buf, "SeX: %.*s", 512, s);
 	sprintf(icon_buf, "%.*s", 512, s);
+#else
+	{
+		char *p;
+		
+		p = strrchr(s, '/');
+		if (p != NULL)
+			s = p + 1;
+		sprintf(title_buf, "%.*s", 512, s);
+		sprintf(icon_buf, "%.*s", 512, s);
+	}
+#endif
 
 	if (sbuf_is_dirty(buf)) {
 		strcat(title_buf, " (modified)");
